import{s as Ve,n as Be,o as Qe}from"../chunks/scheduler.85c25b89.js";import{S as Ye,i as Ze,g as i,s as o,r as p,A as Xe,h as r,f as a,c as l,j as B,u as c,x as s,k as Q,y as m,a as n,v as _,d as u,t as v,w as h}from"../chunks/index.c142fe32.js";import{D as ye}from"../chunks/Docstring.d3e0bcd1.js";import{H as Y,E as et}from"../chunks/EditOnGithub.a592e7aa.js";function tt(Ge){let g,ee,Z,te,$,ae,k,ne,x,Le='Generalized Knowledge Distillation (GKD) was proposed in <a href="https://huggingface.co/papers/2306.13649" rel="nofollow">On-Policy Distillation of Language Models: Learning from Self-Generated Mistakes</a> by Rishabh Agarwal, Nino Vieillard, Yongchao Zhou, Piotr Stanczyk, Sabela Ramos, Matthieu Geist, and Olivier Bachem.',oe,O,Me="The abstract from the paper is the following:",le,y,ze="<p>Knowledge distillation (KD) is widely used for compressing a teacher model to reduce its inference cost and memory footprint, by training a smaller student model. However, current KD methods for auto-regressive sequence models suffer from distribution mismatch between output sequences seen during training and those generated by the student during inference. To address this issue, we introduce Generalized Knowledge Distillation (GKD). Instead of solely relying on a fixed set of output sequences, GKD trains the student on its self-generated output sequences by leveraging feedback from the teacher on such sequences. Unlike supervised KD approaches, GKD also offers the flexibility to employ alternative loss functions between the student and teacher, which can be useful when the student lacks the expressivity to mimic the teacher’s distribution. Furthermore, GKD facilitates the seamless integration of distillation with RL fine-tuning (RLHF). We demonstrate the efficacy of GKD for distilling auto-regressive language models on summarization, translation, and arithmetic reasoning tasks, and task-agnostic distillation for instruction-tuning.</p>",ie,T,He="The key aspects of GKD are:",re,D,Ue="<li>It addresses the train-inference distribution mismatch in auto-regressive sequence models by training the student model on its self-generated output sequences.</li> <li>GKD allows flexibility in choosing different divergence measures between student and teacher models via the generalized Jensen-Shannon Divergence (JSD), which can be useful when the student lacks the capacity to fully mimic the teacher.</li>",se,N,Pe='This post-training method was contributed by <a href="https://huggingface.co/kashif" rel="nofollow">Kashif Rasul</a> and <a href="https://huggingface.co/lewtun" rel="nofollow">Lewis Tunstall</a>',me,K,de,F,qe='The GKD Trainer is a wrapper around the <a href="/docs/trl/main/en/sft_trainer#trl.SFTTrainer">SFTTrainer</a> class that takes in a teacher model argument. It needs two parameters to be set via the <a href="/docs/trl/main/en/gkd_trainer#trl.GKDConfig">GKDConfig</a> namely:',pe,C,Se="<li><code>lmbda</code>:  controls the student data fraction, i.e., the proportion of on-policy student-generated outputs. When <code>lmbda=0.0</code>, the loss reduces to supervised JSD where the student is trained with the token-level probabilities of the teacher. When <code>lmbda=1.0</code>, the loss reduces to on-policy JSD, where the student generates output sequences and token-specific feedback on these sequences from the teacher. For values in between [0, 1] it is random between the two based on the <code>lmbda</code> value for each batch.</li> <li><code>beta</code>: controls the interpolation in the generalized Jensen-Shannon Divergence.  When <code>beta=0.0</code> the loss approximates forward KL divergence, while for <code>beta=1.0</code> the loss approximates reverse KL divergence. For values in between [0, 1] it interpolates between the two.</li>",ce,G,Ee="The authors find that on-policy data (high <code>lmbda</code>) performs better and the optimal <code>beta</code> varied depending on the task and evaluation method.",_e,L,ue,M,Ie="The dataset should be formatted as a list of “messages” where each message is a list of dictionaries with the following keys:",ve,z,Je="<li><code>role</code>: either <code>system</code>, <code>assistant</code> or <code>user</code></li> <li><code>content</code>: the message content</li>",he,H,fe,d,U,Te,w,P,De,J,We='Compute the generalized Jensen-Shannon Divergence loss for knowledge distillation using F.kl_div. See Eq. (1) of <a href="https://arxiv.org/abs/2306.13649" rel="nofollow">https://arxiv.org/abs/2306.13649</a> for the definition.',Ne,f,q,Ke,W,je="Perform a training step for the Generalized Knowledge Distillation (GKD) model.",Fe,j,Re=`This method implements the on-policy learning approach described in the GKD paper.
With probability <code>self.lmbda</code>, it generates new responses using the student model,
which are then used for training instead of the original inputs.`,ge,S,be,b,E,Ce,R,Ae="Configuration class for GKDTrainer.",we,I,$e,X,ke;return $=new Y({props:{title:"Generalized Knowledge Distillation Trainer",local:"generalized-knowledge-distillation-trainer",headingTag:"h1"}}),k=new Y({props:{title:"Overview",local:"overview",headingTag:"h2"}}),K=new Y({props:{title:"Usage tips",local:"usage-tips",headingTag:"h2"}}),L=new Y({props:{title:"Expected dataset format",local:"expected-dataset-format",headingTag:"h3"}}),H=new Y({props:{title:"GKDTrainer",local:"trl.GKDTrainer",headingTag:"h2"}}),U=new ye({props:{name:"class trl.GKDTrainer",anchor:"trl.GKDTrainer",parameters:[{name:"teacher_model",val:": Union"},{name:"args",val:": Optional = None"},{name:"*sft_args",val:""},{name:"**kwargs",val:""}],source:"https://github.com/huggingface/trl/blob/main/trl/trainer/gkd_trainer.py#L40"}}),P=new ye({props:{name:"generalized_jsd_loss",anchor:"trl.GKDTrainer.generalized_jsd_loss",parameters:[{name:"student_logits",val:""},{name:"teacher_logits",val:""},{name:"beta",val:" = 0.5"},{name:"temperature",val:" = 1.0"},{name:"reduction",val:" = 'batchmean'"}],source:"https://github.com/huggingface/trl/blob/main/trl/trainer/gkd_trainer.py#L101",returnDescription:`<script context="module">export const metadata = 'undefined';<\/script>


<p>Scalar tensor with the generalized JSD loss</p>
`,returnType:`<script context="module">export const metadata = 'undefined';<\/script>


<p>loss</p>
`}}),q=new ye({props:{name:"training_step",anchor:"trl.GKDTrainer.training_step",parameters:[{name:"model",val:": Module"},{name:"inputs",val:": Dict"}],source:"https://github.com/huggingface/trl/blob/main/trl/trainer/gkd_trainer.py#L200"}}),S=new Y({props:{title:"GKDConfig",local:"trl.GKDConfig",headingTag:"h2"}}),E=new ye({props:{name:"class trl.GKDConfig",anchor:"trl.GKDConfig",parameters:[{name:"output_dir",val:": str"},{name:"overwrite_output_dir",val:": bool = False"},{name:"do_train",val:": bool = False"},{name:"do_eval",val:": bool = False"},{name:"do_predict",val:": bool = False"},{name:"eval_strategy",val:": Union = 'no'"},{name:"prediction_loss_only",val:": bool = False"},{name:"per_device_train_batch_size",val:": int = 8"},{name:"per_device_eval_batch_size",val:": int = 8"},{name:"per_gpu_train_batch_size",val:": Optional = None"},{name:"per_gpu_eval_batch_size",val:": Optional = None"},{name:"gradient_accumulation_steps",val:": int = 1"},{name:"eval_accumulation_steps",val:": Optional = None"},{name:"eval_delay",val:": Optional = 0"},{name:"torch_empty_cache_steps",val:": Optional = None"},{name:"learning_rate",val:": float = 5e-05"},{name:"weight_decay",val:": float = 0.0"},{name:"adam_beta1",val:": float = 0.9"},{name:"adam_beta2",val:": float = 0.999"},{name:"adam_epsilon",val:": float = 1e-08"},{name:"max_grad_norm",val:": float = 1.0"},{name:"num_train_epochs",val:": float = 3.0"},{name:"max_steps",val:": int = -1"},{name:"lr_scheduler_type",val:": Union = 'linear'"},{name:"lr_scheduler_kwargs",val:": Union = <factory>"},{name:"warmup_ratio",val:": float = 0.0"},{name:"warmup_steps",val:": int = 0"},{name:"log_level",val:": Optional = 'passive'"},{name:"log_level_replica",val:": Optional = 'warning'"},{name:"log_on_each_node",val:": bool = True"},{name:"logging_dir",val:": Optional = None"},{name:"logging_strategy",val:": Union = 'steps'"},{name:"logging_first_step",val:": bool = False"},{name:"logging_steps",val:": float = 500"},{name:"logging_nan_inf_filter",val:": bool = True"},{name:"save_strategy",val:": Union = 'steps'"},{name:"save_steps",val:": float = 500"},{name:"save_total_limit",val:": Optional = None"},{name:"save_safetensors",val:": Optional = True"},{name:"save_on_each_node",val:": bool = False"},{name:"save_only_model",val:": bool = False"},{name:"restore_callback_states_from_checkpoint",val:": bool = False"},{name:"no_cuda",val:": bool = False"},{name:"use_cpu",val:": bool = False"},{name:"use_mps_device",val:": bool = False"},{name:"seed",val:": int = 42"},{name:"data_seed",val:": Optional = None"},{name:"jit_mode_eval",val:": bool = False"},{name:"use_ipex",val:": bool = False"},{name:"bf16",val:": bool = False"},{name:"fp16",val:": bool = False"},{name:"fp16_opt_level",val:": str = 'O1'"},{name:"half_precision_backend",val:": str = 'auto'"},{name:"bf16_full_eval",val:": bool = False"},{name:"fp16_full_eval",val:": bool = False"},{name:"tf32",val:": Optional = None"},{name:"local_rank",val:": int = -1"},{name:"ddp_backend",val:": Optional = None"},{name:"tpu_num_cores",val:": Optional = None"},{name:"tpu_metrics_debug",val:": bool = False"},{name:"debug",val:": Union = ''"},{name:"dataloader_drop_last",val:": bool = False"},{name:"eval_steps",val:": Optional = None"},{name:"dataloader_num_workers",val:": int = 0"},{name:"dataloader_prefetch_factor",val:": Optional = None"},{name:"past_index",val:": int = -1"},{name:"run_name",val:": Optional = None"},{name:"disable_tqdm",val:": Optional = None"},{name:"remove_unused_columns",val:": Optional = True"},{name:"label_names",val:": Optional = None"},{name:"load_best_model_at_end",val:": Optional = False"},{name:"metric_for_best_model",val:": Optional = None"},{name:"greater_is_better",val:": Optional = None"},{name:"ignore_data_skip",val:": bool = False"},{name:"fsdp",val:": Union = ''"},{name:"fsdp_min_num_params",val:": int = 0"},{name:"fsdp_config",val:": Union = None"},{name:"fsdp_transformer_layer_cls_to_wrap",val:": Optional = None"},{name:"accelerator_config",val:": Union = None"},{name:"deepspeed",val:": Union = None"},{name:"label_smoothing_factor",val:": float = 0.0"},{name:"optim",val:": Union = 'adamw_torch'"},{name:"optim_args",val:": Optional = None"},{name:"adafactor",val:": bool = False"},{name:"group_by_length",val:": bool = False"},{name:"length_column_name",val:": Optional = 'length'"},{name:"report_to",val:": Union = None"},{name:"ddp_find_unused_parameters",val:": Optional = None"},{name:"ddp_bucket_cap_mb",val:": Optional = None"},{name:"ddp_broadcast_buffers",val:": Optional = None"},{name:"dataloader_pin_memory",val:": bool = True"},{name:"dataloader_persistent_workers",val:": bool = False"},{name:"skip_memory_metrics",val:": bool = True"},{name:"use_legacy_prediction_loop",val:": bool = False"},{name:"push_to_hub",val:": bool = False"},{name:"resume_from_checkpoint",val:": Optional = None"},{name:"hub_model_id",val:": Optional = None"},{name:"hub_strategy",val:": Union = 'every_save'"},{name:"hub_token",val:": Optional = None"},{name:"hub_private_repo",val:": bool = False"},{name:"hub_always_push",val:": bool = False"},{name:"gradient_checkpointing",val:": bool = False"},{name:"gradient_checkpointing_kwargs",val:": Union = None"},{name:"include_inputs_for_metrics",val:": bool = False"},{name:"eval_do_concat_batches",val:": bool = True"},{name:"fp16_backend",val:": str = 'auto'"},{name:"evaluation_strategy",val:": Union = None"},{name:"push_to_hub_model_id",val:": Optional = None"},{name:"push_to_hub_organization",val:": Optional = None"},{name:"push_to_hub_token",val:": Optional = None"},{name:"mp_parameters",val:": str = ''"},{name:"auto_find_batch_size",val:": bool = False"},{name:"full_determinism",val:": bool = False"},{name:"torchdynamo",val:": Optional = None"},{name:"ray_scope",val:": Optional = 'last'"},{name:"ddp_timeout",val:": Optional = 1800"},{name:"torch_compile",val:": bool = False"},{name:"torch_compile_backend",val:": Optional = None"},{name:"torch_compile_mode",val:": Optional = None"},{name:"dispatch_batches",val:": Optional = None"},{name:"split_batches",val:": Optional = None"},{name:"include_tokens_per_second",val:": Optional = False"},{name:"include_num_input_tokens_seen",val:": Optional = False"},{name:"neftune_noise_alpha",val:": Optional = None"},{name:"optim_target_modules",val:": Union = None"},{name:"batch_eval_metrics",val:": bool = False"},{name:"eval_on_start",val:": bool = False"},{name:"use_liger_kernel",val:": Optional = False"},{name:"eval_use_gather_object",val:": Optional = False"},{name:"dataset_text_field",val:": Optional = None"},{name:"packing",val:": bool = False"},{name:"max_seq_length",val:": Optional = None"},{name:"dataset_num_proc",val:": Optional = None"},{name:"dataset_batch_size",val:": int = 1000"},{name:"model_init_kwargs",val:": Optional = None"},{name:"dataset_kwargs",val:": Optional = None"},{name:"eval_packing",val:": Optional = None"},{name:"num_of_sequences",val:": int = 1024"},{name:"chars_per_token",val:": float = 3.6"},{name:"use_liger",val:": bool = False"},{name:"temperature",val:": float = 0.9"},{name:"lmbda",val:": float = 0.5"},{name:"beta",val:": float = 0.5"},{name:"max_new_tokens",val:": int = 128"},{name:"teacher_model_name_or_path",val:": Optional = None"},{name:"teacher_model_init_kwargs",val:": Optional = None"},{name:"disable_dropout",val:": bool = True"}],parametersDescription:[{anchor:"trl.GKDConfig.temperature",description:`<strong>temperature</strong> (<code>float</code>, <em>optional</em>, defaults to <code>0.9</code>) &#x2014;
Temperature for sampling. The higher the temperature, the more random the completions.`,name:"temperature"},{anchor:"trl.GKDConfig.lmbda",description:`<strong>lmbda</strong> (<code>float</code>, <em>optional</em>, defaults to <code>0.5</code>) &#x2014;
Lambda parameter that controls the student data fraction (i.e., the proportion of on-policy
student-generated outputs).`,name:"lmbda"},{anchor:"trl.GKDConfig.beta",description:`<strong>beta</strong> (<code>float</code>, <em>optional</em>, defaults to <code>0.5</code>) &#x2014;
Interpolation coefficient between <code>0.0</code> and <code>1.0</code> of the Generalized Jensen-Shannon Divergence loss. When
beta is <code>0.0</code>, the loss is the KL divergence. When beta is <code>1.0</code>, the loss is the Inverse KL Divergence.`,name:"beta"},{anchor:"trl.GKDConfig.max_new_tokens",description:`<strong>max_new_tokens</strong> (<code>int</code>, <em>optional</em>, defaults to <code>128</code>) &#x2014;
Maximum number of tokens to generate per completion.`,name:"max_new_tokens"},{anchor:"trl.GKDConfig.teacher_model_name_or_path",description:`<strong>teacher_model_name_or_path</strong> (<code>Optional[str]</code>, <em>optional</em>, defaults to <code>None</code>) &#x2014;
Model name or path of the teacher model. If <code>None</code>, the teacher model will be the same as the model
being trained.`,name:"teacher_model_name_or_path"},{anchor:"trl.GKDConfig.teacher_model_init_kwargs",description:`<strong>teacher_model_init_kwargs</strong> (<code>Optional[Dict[str, Any]]</code>, <em>optional</em>, defaults to <code>None</code>) &#x2014;
Keyword arguments to pass to <code>AutoModelForCausalLM.from_pretrained</code> when instantiating the teacher model
from a string.`,name:"teacher_model_init_kwargs"},{anchor:"trl.GKDConfig.disable_dropout",description:`<strong>disable_dropout</strong> (<code>bool</code>, <em>optional</em>, defaults to <code>True</code>) &#x2014;
Whether or not to disable dropouts in <code>model</code>.`,name:"disable_dropout"}],source:"https://github.com/huggingface/trl/blob/main/trl/trainer/gkd_config.py#L20"}}),I=new et({props:{source:"https://github.com/huggingface/trl/blob/main/docs/source/gkd_trainer.md"}}),{c(){g=i("meta"),ee=o(),Z=i("p"),te=o(),p($.$$.fragment),ae=o(),p(k.$$.fragment),ne=o(),x=i("p"),x.innerHTML=Le,oe=o(),O=i("p"),O.textContent=Me,le=o(),y=i("blockquote"),y.innerHTML=ze,ie=o(),T=i("p"),T.textContent=He,re=o(),D=i("ol"),D.innerHTML=Ue,se=o(),N=i("p"),N.innerHTML=Pe,me=o(),p(K.$$.fragment),de=o(),F=i("p"),F.innerHTML=qe,pe=o(),C=i("ul"),C.innerHTML=Se,ce=o(),G=i("p"),G.innerHTML=Ee,_e=o(),p(L.$$.fragment),ue=o(),M=i("p"),M.textContent=Ie,ve=o(),z=i("ul"),z.innerHTML=Je,he=o(),p(H.$$.fragment),fe=o(),d=i("div"),p(U.$$.fragment),Te=o(),w=i("div"),p(P.$$.fragment),De=o(),J=i("p"),J.innerHTML=We,Ne=o(),f=i("div"),p(q.$$.fragment),Ke=o(),W=i("p"),W.textContent=je,Fe=o(),j=i("p"),j.innerHTML=Re,ge=o(),p(S.$$.fragment),be=o(),b=i("div"),p(E.$$.fragment),Ce=o(),R=i("p"),R.textContent=Ae,we=o(),p(I.$$.fragment),$e=o(),X=i("p"),this.h()},l(e){const t=Xe("svelte-u9bgzb",document.head);g=r(t,"META",{name:!0,content:!0}),t.forEach(a),ee=l(e),Z=r(e,"P",{}),B(Z).forEach(a),te=l(e),c($.$$.fragment,e),ae=l(e),c(k.$$.fragment,e),ne=l(e),x=r(e,"P",{"data-svelte-h":!0}),s(x)!=="svelte-18hccem"&&(x.innerHTML=Le),oe=l(e),O=r(e,"P",{"data-svelte-h":!0}),s(O)!=="svelte-vfdo9a"&&(O.textContent=Me),le=l(e),y=r(e,"BLOCKQUOTE",{"data-svelte-h":!0}),s(y)!=="svelte-okqzjb"&&(y.innerHTML=ze),ie=l(e),T=r(e,"P",{"data-svelte-h":!0}),s(T)!=="svelte-18ffga0"&&(T.textContent=He),re=l(e),D=r(e,"OL",{"data-svelte-h":!0}),s(D)!=="svelte-1syfv1j"&&(D.innerHTML=Ue),se=l(e),N=r(e,"P",{"data-svelte-h":!0}),s(N)!=="svelte-17e2lfn"&&(N.innerHTML=Pe),me=l(e),c(K.$$.fragment,e),de=l(e),F=r(e,"P",{"data-svelte-h":!0}),s(F)!=="svelte-l0w5iv"&&(F.innerHTML=qe),pe=l(e),C=r(e,"UL",{"data-svelte-h":!0}),s(C)!=="svelte-1dreu47"&&(C.innerHTML=Se),ce=l(e),G=r(e,"P",{"data-svelte-h":!0}),s(G)!=="svelte-1l3unnm"&&(G.innerHTML=Ee),_e=l(e),c(L.$$.fragment,e),ue=l(e),M=r(e,"P",{"data-svelte-h":!0}),s(M)!=="svelte-13p3krv"&&(M.textContent=Ie),ve=l(e),z=r(e,"UL",{"data-svelte-h":!0}),s(z)!=="svelte-mdo3up"&&(z.innerHTML=Je),he=l(e),c(H.$$.fragment,e),fe=l(e),d=r(e,"DIV",{class:!0});var A=B(d);c(U.$$.fragment,A),Te=l(A),w=r(A,"DIV",{class:!0});var xe=B(w);c(P.$$.fragment,xe),De=l(xe),J=r(xe,"P",{"data-svelte-h":!0}),s(J)!=="svelte-pbnab8"&&(J.innerHTML=We),xe.forEach(a),Ne=l(A),f=r(A,"DIV",{class:!0});var V=B(f);c(q.$$.fragment,V),Ke=l(V),W=r(V,"P",{"data-svelte-h":!0}),s(W)!=="svelte-11q3tvu"&&(W.textContent=je),Fe=l(V),j=r(V,"P",{"data-svelte-h":!0}),s(j)!=="svelte-1q3d8k1"&&(j.innerHTML=Re),V.forEach(a),A.forEach(a),ge=l(e),c(S.$$.fragment,e),be=l(e),b=r(e,"DIV",{class:!0});var Oe=B(b);c(E.$$.fragment,Oe),Ce=l(Oe),R=r(Oe,"P",{"data-svelte-h":!0}),s(R)!=="svelte-1eu3l6e"&&(R.textContent=Ae),Oe.forEach(a),we=l(e),c(I.$$.fragment,e),$e=l(e),X=r(e,"P",{}),B(X).forEach(a),this.h()},h(){Q(g,"name","hf:doc:metadata"),Q(g,"content",at),Q(w,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),Q(f,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),Q(d,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8"),Q(b,"class","docstring border-l-2 border-t-2 pl-4 pt-3.5 border-gray-100 rounded-tl-xl mb-6 mt-8")},m(e,t){m(document.head,g),n(e,ee,t),n(e,Z,t),n(e,te,t),_($,e,t),n(e,ae,t),_(k,e,t),n(e,ne,t),n(e,x,t),n(e,oe,t),n(e,O,t),n(e,le,t),n(e,y,t),n(e,ie,t),n(e,T,t),n(e,re,t),n(e,D,t),n(e,se,t),n(e,N,t),n(e,me,t),_(K,e,t),n(e,de,t),n(e,F,t),n(e,pe,t),n(e,C,t),n(e,ce,t),n(e,G,t),n(e,_e,t),_(L,e,t),n(e,ue,t),n(e,M,t),n(e,ve,t),n(e,z,t),n(e,he,t),_(H,e,t),n(e,fe,t),n(e,d,t),_(U,d,null),m(d,Te),m(d,w),_(P,w,null),m(w,De),m(w,J),m(d,Ne),m(d,f),_(q,f,null),m(f,Ke),m(f,W),m(f,Fe),m(f,j),n(e,ge,t),_(S,e,t),n(e,be,t),n(e,b,t),_(E,b,null),m(b,Ce),m(b,R),n(e,we,t),_(I,e,t),n(e,$e,t),n(e,X,t),ke=!0},p:Be,i(e){ke||(u($.$$.fragment,e),u(k.$$.fragment,e),u(K.$$.fragment,e),u(L.$$.fragment,e),u(H.$$.fragment,e),u(U.$$.fragment,e),u(P.$$.fragment,e),u(q.$$.fragment,e),u(S.$$.fragment,e),u(E.$$.fragment,e),u(I.$$.fragment,e),ke=!0)},o(e){v($.$$.fragment,e),v(k.$$.fragment,e),v(K.$$.fragment,e),v(L.$$.fragment,e),v(H.$$.fragment,e),v(U.$$.fragment,e),v(P.$$.fragment,e),v(q.$$.fragment,e),v(S.$$.fragment,e),v(E.$$.fragment,e),v(I.$$.fragment,e),ke=!1},d(e){e&&(a(ee),a(Z),a(te),a(ae),a(ne),a(x),a(oe),a(O),a(le),a(y),a(ie),a(T),a(re),a(D),a(se),a(N),a(me),a(de),a(F),a(pe),a(C),a(ce),a(G),a(_e),a(ue),a(M),a(ve),a(z),a(he),a(fe),a(d),a(ge),a(be),a(b),a(we),a($e),a(X)),a(g),h($,e),h(k,e),h(K,e),h(L,e),h(H,e),h(U),h(P),h(q),h(S,e),h(E),h(I,e)}}}const at='{"title":"Generalized Knowledge Distillation Trainer","local":"generalized-knowledge-distillation-trainer","sections":[{"title":"Overview","local":"overview","sections":[],"depth":2},{"title":"Usage tips","local":"usage-tips","sections":[{"title":"Expected dataset format","local":"expected-dataset-format","sections":[],"depth":3}],"depth":2},{"title":"GKDTrainer","local":"trl.GKDTrainer","sections":[],"depth":2},{"title":"GKDConfig","local":"trl.GKDConfig","sections":[],"depth":2}],"depth":1}';function nt(Ge){return Qe(()=>{new URLSearchParams(window.location.search).get("fw")}),[]}class st extends Ye{constructor(g){super(),Ze(this,g,nt,tt,Ve,{})}}export{st as component};
